@@ -66,19 +66,18 @@
 #' inference from animal movement data. Scientific Reports 6:20625
 #' 
 #' @examples
-#' \dontrun{
-#' # Fit DCRW model for state filtering and regularization
-#' data(ellie)
-#' fit <- fit_ssm(ellie, model = "DCRW", tstep = 2, adapt = 5000, samples = 5000, 
-#'               thin = 5, span = 0.2)
-#' diag_ssm(fit)
-#' map_ssm(fit)
-#' plot_fit(fit)
-#' result <- get_summary(fit)
 #' 
-#' # Fit DCRWS model for state filtering, regularization and behavioural state estimation
-#'  fit.s <- fit_ssm(ellie, model = "DCRWS", tstep = 2, adapt = 5000, samples = 5000, 
-#'                 thin = 5, span = 0.2)
+#' # Fit DCRW model for state filtering and regularization - 
+#' # using trivial adapt & samples values for speed
+#' data(ellie1)
+#' fit <- fit_ssm(ellie1, model = "DCRW", tstep = 4, adapt = 10, samples = 100, 
+#'               thin = 1, span = 0.2)
+#' 
+#' \donttest{
+#' # Fit DCRWS model for state filtering, regularization and behavioural state estimation - 
+#' # using trivial adapt & samples values for speed
+#'  fit.s <- fit_ssm(ellie1, model = "DCRWS", tstep = 2, adapt = 10, samples = 100, 
+#'                 thin = 1, span = 0.2)
 #'  diag_ssm(fit.s)
 #'  map_ssm(fit.s)
 #'  plot_fit(fit.s)
@@ -86,15 +85,17 @@
 #' 
 #' # fit hDCRWS model to > 1 tracks simultaneously
 #' # this may provide better parameter and behavioural state estimation 
-#' # by borrowing strength across multiple track datasets
-#'  hfit.s <- fit_ssm(ellie, model = "hDCRWS", tstep = 2, adapt = 5000, samples = 5000, 
-#'                 thin = 5, span = 0.2)
-#'  diag_ssm(hfit.s)
-#'  map_ssm(hfit.s)
-#'  plot_fit(hfit.s)
-#'  result.hs <- get_summary(hfit.s)
+#' # by borrowing strength across multiple track datasets - 
+#' # using trivial adapt & samples values for speed
+#' data(ellie2)
+#' hfit.s <- fit_ssm(ellie2, model = "hDCRWS", tstep = 2, adapt = 10, samples = 100, 
+#'                 thin = 1, span = 0.2)
+#' diag_ssm(hfit.s)
+#' map_ssm(hfit.s)
+#' plot_fit(hfit.s)
+#' result.hs <- get_summary(hfit.s)
 #' }
-#' @importFrom tibble as_data_frame
+#' @importFrom tibble as_tibble
 #' @export 
 fit_ssm <- function (data, model = "DCRW", tstep = 1, adapt = 10000, samples = 5000, 
                     thin = 5, span = 0.2)
@@ -110,7 +111,7 @@ fit_ssm <- function (data, model = "DCRW", tstep = 1, adapt = 10000, samples = 5
   id <- data$id
   data$id <- tmp.id
   
-  data <- as_data_frame(data)
+  data <- as_tibble(data)
  
 	d <- dat4jags(data, tstep = tstep, tpar=tpar())	
 
